@@ -11,6 +11,7 @@ nsim will look at y0 to determine what type of variable is being used.
 
 import nsim
 import numpy as np
+from distob import gather
 
 
 class Osc(nsim.SDEModel):
@@ -30,12 +31,16 @@ class Osc(nsim.SDEModel):
     
 
 sims = nsim.RepeatedSim(Osc, T=1440.0, repeat=10)
-
 ts = sims.timeseries
+means = ts.mean(axis=0)
+
+# ufunc support (including array subtraction) for distributed arrays is not yet
+# implemented. Temporary workaround: gather timeseries to make them local first
+ts = gather(ts)
+means = gather(means)
 
-means = np.array([ts.mean(axis=0) for s in sims]).mean()
 phases = (ts - means).angle()
 phases.plot(title='phase at each node')
-phases[:,:,1].t[300:360].plot(title='phase') # show 60 seconds of node 1
+phases[:,:,3].t[100:160].plot(title='phase') # show 60 seconds of node 3
 
 print('mean period is %g seconds' % phases[:,:,1].periods().mean())
