@@ -11,10 +11,10 @@ from .pyeeg import (hurst, embed_seq, in_range, bin_power, first_order_diff,
                     pfd, hfd, hjorth, spectral_entropy, svd_entropy, 
                     fisher_info, ap_entropy, samp_entropy, dfa)
 
-__all__ = ['snapshots', 'psd', 'lowpass', 'highpass', 'bandpass', 'notch',
-           'hilbert', 'hilbert_amplitude', 'hilbert_phase', 'cwt',
-           'cwt_distributed', 'variability_fp', 'epochs', 'epochs_distributed',
-           'epochs_joint', 'plot', 'mod2pi', 'crossing_indices', 'periods']
+__all__ = ['psd', 'lowpass', 'highpass', 'bandpass', 'notch', 'hilbert',
+           'hilbert_amplitude', 'hilbert_phase', 'cwt', 'cwt_distributed',
+           'variability_fp', 'epochs', 'epochs_distributed', 'epochs_joint',
+           'plot', 'mod2pi', 'crossing_indices', 'periods']
 
 __all__ += ['variability_fp', 'epochs', 'epochs_distributed', 'epochs_joint']
 
